@@ -1,5 +1,5 @@
 /* cmdline.c
-   Copyright (C) 2005,2006,2007 Eugene K. Ressler, Jr.
+   Copyright (C) 2005,2006,2007,2008 Eugene K. Ressler, Jr.
 
 This file is part of Sketch, a small, simple system for making 
 3d drawings with LaTeX and the PSTricks or TikZ package.
@@ -20,11 +20,11 @@ http://www.gnu.org/copyleft */
 
 #include <stdlib.h>
 #include "cmdline.h"
+#include "emit.h"
 #include "memutil.h"
-#include "version.h"
 #include "parse.h"
 #include "symbol.h"
-#include "emit.h"
+#include "version.h"
 
 void
 usage (int exit_code)
@@ -33,6 +33,7 @@ usage (int exit_code)
 	   "sketch [options] file1 [-D tag][-U tag] file2...\n"
 	   "-h                 Print this message to standard error\n"
 	   "-v                 Print version info to standard output\n"
+	   "-V x.y             Tell Sketch your PSTricks or TikZ version is x.y\n"
 	   "-d                 Debug parser (for developers)\n"
 	   "-b                 Use BSP rather than Painters algorithm for HSR\n"
 	   "-T[u|e][p[P|T]]    Produce a complete LaTeX document\n"
@@ -76,6 +77,8 @@ process_global_options (CMD_LINE_OPT_ENV * env, int argc, char **argv,
   // n_files = 0
   SET_STRUCT_ZERO (env);
   env->sym_tab = sym_tab;
+  parse_pst_version(env->pst_version, STRINGIFY(ASSUMED_PST_VERSION), no_line);
+  parse_tikz_version(env->tikz_version, STRINGIFY(ASSUMED_TIKZ_VERSION), no_line);
 
   // we'll copy args that need to be processed in order with filenames here.
   // the convention will be that args with paramaters like -Dfoo will be 
@@ -195,8 +198,31 @@ process_global_options (CMD_LINE_OPT_ENV * env, int argc, char **argv,
 		       argv[i][j]);
 		}
 	      break;
+	    case 'V':
+	      if (argv[i][2] != '\0')
+		{
+		  parse_pst_version(env->pst_version, &argv[i][2], no_line);
+		  parse_tikz_version(env->tikz_version, &argv[i][2], no_line);
+		}
+	      else 
+		{
+		  if (i + 1 < argc) 
+		    {
+		      ++i;
+		      parse_pst_version(env->pst_version, &argv[i][0], no_line);
+		      parse_tikz_version(env->pst_version, &argv[i][0], no_line);
+		    }
+		  else
+		    {
+		      err (no_line, "missing PSTricks or TikZ version after -V");
+		    }
+		}
+	      break;
 	    case 'v':
 	      fprintf (stdout, "%% sketch version %s\n", VER_STRING);
+	      fprintf (stdout, "%% assumes PSTricks version %s\n", env->pst_version->str);
+	      fprintf (stdout, "%% assumes TikZ version %s\n", env->tikz_version->str);
+	      fprintf (stdout, "%% use -V to select earlier versions\n");
 	      env->skip_input_p = 1;
 	      break;
 	    default:
