@@ -1,5 +1,5 @@
 /* cmdline.h
-   Copyright (C) 2005,2006,2007 Eugene K. Ressler, Jr.
+   Copyright (C) 2005,2006,2007,2008 Eugene K. Ressler, Jr.
 
 This file is part of Sketch, a small, simple system for making 
 3d drawings with LaTeX and the PSTricks or TikZ package.
@@ -21,19 +21,22 @@ http://www.gnu.org/copyleft */
 #ifndef __CMDLINE_H
 #define __CMDLINE_H
 
+#include "langver.h"
 #include "symbol.h"
 
 typedef struct cmd_opt_env_t
 {
-  int i;			// index of opt currently being processed (init zero)
-  int argc;			// cmd line param count
-  char **argv;			// cmd line params
-  SYMBOL_TABLE *sym_tab;	// symbol table
-  int bsp_only_p;		// bsp only (default off)
-  char *doc_template_file_name;	// document template file name (default NULL)
-  char *out_file_name;		// output file name (default NULL for stdout)
-  int skip_input_p;		// true for options where processing input makes no sense
-  int n_files;                  // number of input file names
+  int i;			  // index of opt currently being processed (init zero)
+  int argc;			  // cmd line param count
+  char **argv;			  // cmd line params
+  SYMBOL_TABLE *sym_tab;          // symbol table
+  int bsp_only_p;		  // bsp only (default off)
+  char *doc_template_file_name;   // document template file name (default NULL)
+  char *out_file_name;		  // output file name (default NULL for stdout)
+  int skip_input_p;		  // true for options where processing input makes no sense
+  int n_files;                    // number of input file names
+  PST_VERSION pst_version[1];     // version of pstricks to generate for output
+  TIKZ_VERSION tikz_version[1];   // version of tikz to generate for output
 }
 CMD_LINE_OPT_ENV;
 
