@@ -151,7 +151,7 @@ process_special (FILE * f, SPECIAL_OBJECT * special, SRC_LINE line)
   char ch, buf1[16], buf2[16];
   int i_arg_prev, i_arg, arg_len, arg_index_1, arg_index_2;
 
-  i_arg_prev = i_arg = 0;
+  i_arg_prev = i_arg = arg_index_1 = arg_index_2 = 0;
   while ((ch = special->code[i_arg]) != '\0')
     {
       if (ch == '#')
@@ -165,22 +165,17 @@ process_special (FILE * f, SPECIAL_OBJECT * special, SRC_LINE line)
 	    }
 	  else
 	    {
-	      switch (scan_special_arg
-		      (special, i_arg + 1, &arg_len, &arg_index_1,
-		       &arg_index_2, line))
+	      switch (scan_special_arg(special, i_arg + 1, &arg_len, &arg_index_1, &arg_index_2, line))
 		{
 		case 2:
 		  if (f)
 		    fprintf (f, "%.*s{%s}", i_arg - i_arg_prev,	// number of chars to write
 			     &special->code[i_arg_prev],	// start of chars
-			     (*fmt_angle_tbl
-			      [global_env->output_language])
-			     (buf1,
-			      180 / PI *
-			      atan2 (special->pts->v[arg_index_2][Y] -
-				     special->pts->v[arg_index_1][Y],
-				     special->pts->v[arg_index_2][X] -
-				     special->pts->v[arg_index_1][X]), line));
+			     (*fmt_angle_tbl[global_env->output_language])(buf1,
+			       180 / PI * 
+			       atan2(special->pts->v[arg_index_2][Y] - special->pts->v[arg_index_1][Y],
+				     special->pts->v[arg_index_2][X] - special->pts->v[arg_index_1][X]), 
+                               line));
 		  break;
 		case 1:
 		  if (f)
@@ -616,7 +611,6 @@ void
 emit_preamble_tkz_latex (FILE * f, BOX_3D * ext, GLOBAL_ENV * env)
 {
   char buf1[16], buf2[16], buf3[16], buf4[16];
-  int picture_opts_p = 0;
 
   if (global_env_is_set_p (env, GE_FRAME))
     {
@@ -706,7 +700,6 @@ void
 emit_preamble_tkz_context (FILE * f, BOX_3D * ext, GLOBAL_ENV * env)
 {
   char buf1[16], buf2[16], buf3[16], buf4[16];
-  int picture_opts_p = 0;
 
   if (global_env_is_set_p (env, GE_FRAME))
     {
@@ -839,7 +832,7 @@ emit (FILE * f, OBJECT * obj, GLOBAL_ENV * env, char *doc_template_file_name)
 	{
 	  escape = strstr (doc_template, DOC_TEMPLATE_ESCAPE_STRING);
 	  if (escape)
-	    fprintf (f, "%.*s", escape - doc_template, doc_template);
+	    fprintf (f, "%.*s", (int)(escape - doc_template), doc_template);
 	  else
 	    warn (no_line,
 		  "document template with no escape '%s' has been ignored",
