@@ -1,5 +1,5 @@
 /* scene.c
-   Copyright (C) 2005,2006,2007 Eugene K. Ressler, Jr.
+   Copyright (C) 2005,2006,2007,2008 Eugene K. Ressler, Jr.
 
 This file is part of Sketch, a small, simple system for making 
 3d drawings with LaTeX and the PSTricks or TikZ package.
@@ -50,7 +50,7 @@ DECLARE_DYNAMIC_2D_ARRAY_FUNCS (TRANSFORM_LIST, TRANSFORM, FLOAT,
 #define LAY_OVER 1
 #define LAY_UNDER -1
 
-     int lay_val (OPTS * opts, int lay_default)
+int lay_val (OPTS * opts, int lay_default)
 {
   char *val = opt_val (opts, "lay");
   if (!val)
@@ -59,6 +59,8 @@ DECLARE_DYNAMIC_2D_ARRAY_FUNCS (TRANSFORM_LIST, TRANSFORM, FLOAT,
     return LAY_OVER;
   else if (strcmp (val, "under") == 0)
     return LAY_UNDER;
+  else if (strcmp (val, "in") == 0)
+    return LAY_IN;
   else
     {
       warn (no_line, "lay=%s has been ignored", val);
@@ -402,6 +404,12 @@ static COPY_FUNC copy_tbl[] = {
   copy_compound,
 };
 
+OBJECT *
+copy_drawable_without_siblings(OBJECT * obj)
+{
+  return (*copy_tbl[obj->tag]) (obj);
+}
+
 OBJECT *
 copy_drawable (OBJECT * obj)
 {
@@ -410,7 +418,7 @@ copy_drawable (OBJECT * obj)
     {
       if (copy_tbl[obj->tag])
 	{
-	  OBJECT *copy = (*copy_tbl[obj->tag]) (obj);
+	  OBJECT *copy = copy_drawable_without_siblings(obj);
 	  copy->sibling = r;
 	  r = copy;
 	}
@@ -1388,7 +1396,7 @@ hsr_scene_with_bsp (OBJECT * scene)
       switch (object_lay_val (p))
 	{
 	case LAY_UNDER:
-	  t = copy_drawable (p);
+	  t = copy_drawable_without_siblings (p);
 	  t->sibling = underlay;
 	  underlay = t;
 	  break;
@@ -1396,7 +1404,7 @@ hsr_scene_with_bsp (OBJECT * scene)
 	  (*insert_in_bsp_pass_1_tbl[p->tag]) (p, &bsp);
 	  break;
 	case LAY_OVER:
-	  t = copy_drawable (p);
+	  t = copy_drawable_without_siblings (p);
 	  t->sibling = overlay;
 	  overlay = t;
 	  break;
@@ -1512,7 +1520,7 @@ hsr_scene_with_depth_sort (OBJECT * scene)
       switch (object_lay_val (p))
 	{
 	case LAY_UNDER:
-	  t = copy_drawable (p);
+	  t = copy_drawable_without_siblings (p);
 	  t->sibling = underlay;
 	  underlay = t;
 	  break;
@@ -1520,7 +1528,7 @@ hsr_scene_with_depth_sort (OBJECT * scene)
 	  (*add_to_sort_tbl[p->tag]) (p, &bsp);
 	  break;
 	case LAY_OVER:
-	  t = copy_drawable (p);
+	  t = copy_drawable_without_siblings (p);
 	  t->sibling = overlay;
 	  overlay = t;
 	  break;
@@ -1609,8 +1617,7 @@ get_extent (OBJECT * obj, BOX_3D * e, int *n_obj)
   if (obj)
     {
       int n = 0;
-      e->min[X] = e->min[Y] = e->min[Z] = FLOAT_MAX;
-      e->max[X] = e->max[X] = e->max[X] = FLOAT_MIN;
+      init_box_3d(e);
       while (obj)
 	{
 	  if (extent_tbl[obj->tag] == NULL)
@@ -1625,7 +1632,7 @@ get_extent (OBJECT * obj, BOX_3D * e, int *n_obj)
     {
       // reasonable empty box
       e->min[X] = e->min[Y] = e->min[Z] = 0;
-      e->max[X] = e->max[X] = e->max[X] = 1;
+      e->max[X] = e->max[Y] = e->max[Z] = 1;
       *n_obj = 0;
     }
 }
@@ -1634,9 +1641,12 @@ int
 xy_overlap_p (OBJECT * obj, BOX_3D * e)
 {
   BOX_3D e_obj[1];
+
+  init_box_3d(e_obj);
   (*extent_tbl[obj->tag]) (obj, e_obj);
-  return
-    e_obj->max[X] > e->min[X] ||
-    e_obj->min[X] < e->max[X] ||
-    e_obj->max[Y] > e->min[Y] || e_obj->min[Y] < e->max[Y];
+  return 
+    !(e_obj->max[X] < e->min[X] ||
+      e_obj->min[X] > e->max[X] ||
+      e_obj->max[Y] < e->min[Y] || 
+      e_obj->min[Y] > e->max[Y]);
 }
