@@ -157,18 +157,19 @@
 #include <stdlib.h>
 
 #if defined(_WIN32)
-#include <malloc.h>
-#if !defined(alloca)
-#define alloca _alloca
-#endif
-#define YYSTACK_USE_ALLOCA 1
-// turn of warning about unused goto label in bison skeleton
-#pragma warning(disable:4102)
+#  include <malloc.h>
+#  if !defined(alloca)
+#    define alloca _alloca
+#  endif
+#  ifdef _MSC_VER
+     // turn of warning about unused goto label in bison skeleton
+#    pragma warning(disable:4102)
+#  endif
+#  define YYSTACK_USE_ALLOCA 1
 #endif
 
 #include "parse.h"
 #include "expr.h"
-#include "bsp.h"
 #include "global.h"
 
 int yylex(void);
@@ -180,8 +181,6 @@ void yyerror (char *s)  /* Called by yyparse on error */
 }
 
 static SYMBOL_TABLE *sym_tab;
-static BSP_TREE bsp;
-static FILE *yyout;
 
 // exported parse tree and global environment
 static OBJECT *objects;
@@ -207,7 +206,7 @@ static OBJECT *objects;
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 58 "sketch.y"
+#line 57 "sketch.y"
 typedef union YYSTYPE {
   char *str;
   FLOAT flt;
@@ -222,7 +221,7 @@ typedef union YYSTYPE {
   int index;
 } YYSTYPE;
 /* Line 196 of yacc.c.  */
-#line 226 "y.tab.c"
+#line 225 "y.tab.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -234,7 +233,7 @@ typedef union YYSTYPE {
 
 
 /* Line 219 of yacc.c.  */
-#line 238 "y.tab.c"
+#line 237 "y.tab.c"
 
 #if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
 # define YYSIZE_T __SIZE_TYPE__
@@ -508,18 +507,18 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned short int yyrline[] =
 {
-       0,   105,   105,   108,   109,   112,   113,   116,   120,   124,
-     129,   133,   137,   141,   145,   148,   151,   152,   155,   156,
-     159,   160,   163,   164,   167,   170,   171,   174,   175,   179,
-     180,   181,   184,   185,   188,   189,   190,   193,   194,   195,
-     196,   197,   201,   205,   209,   210,   211,   212,   213,   214,
-     213,   223,   224,   227,   231,   238,   239,   240,   241,   244,
-     247,   248,   251,   254,   255,   258,   259,   260,   261,   262,
-     263,   264,   265,   266,   267,   268,   269,   270,   271,   272,
-     273,   274,   275,   276,   277,   280,   281,   284,   287,   291,
-     295,   298,   301,   305,   309,   311,   314,   326,   330,   340,
-     344,   348,   365,   366,   367,   368,   378,   388,   393,   394,
-     397
+       0,   104,   104,   107,   108,   111,   112,   115,   119,   123,
+     128,   132,   136,   140,   144,   147,   150,   151,   154,   155,
+     158,   159,   162,   163,   166,   169,   170,   173,   174,   178,
+     179,   180,   183,   184,   187,   188,   189,   192,   193,   194,
+     195,   196,   200,   204,   208,   209,   210,   211,   212,   213,
+     212,   222,   223,   226,   230,   237,   238,   239,   240,   243,
+     246,   247,   250,   253,   254,   257,   258,   259,   260,   261,
+     262,   263,   264,   265,   266,   267,   268,   269,   270,   271,
+     272,   273,   274,   275,   276,   279,   280,   283,   286,   290,
+     294,   297,   300,   304,   308,   310,   313,   325,   329,   339,
+     343,   347,   364,   365,   366,   367,   377,   387,   392,   393,
+     396
 };
 #endif
 
@@ -1508,26 +1507,26 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 105 "sketch.y"
+#line 104 "sketch.y"
     { objects = (yyvsp[-1].obj); }
     break;
 
   case 7:
-#line 117 "sketch.y"
+#line 116 "sketch.y"
     { 
                             set_global_env_opts(global_env, (yyvsp[0].str), line);
                           }
     break;
 
   case 8:
-#line 121 "sketch.y"
+#line 120 "sketch.y"
     { 
                             set_global_baseline(global_env, (yyvsp[-1].flt), line);
                           }
     break;
 
   case 9:
-#line 125 "sketch.y"
+#line 124 "sketch.y"
     { 
                             set_global_baseline(global_env, (yyvsp[-2].flt), line);
                             set_global_env_extent(global_env, (yyvsp[-1].pt), (yyvsp[0].pt), line);
@@ -1535,216 +1534,216 @@ yyreduce:
     break;
 
   case 10:
-#line 130 "sketch.y"
+#line 129 "sketch.y"
     {
                             set_global_env_camera(global_env, (yyvsp[0].xf), line);
                           }
     break;
 
   case 11:
-#line 134 "sketch.y"
+#line 133 "sketch.y"
     { 
                             set_global_env_frame(global_env, NULL, line);
                           }
     break;
 
   case 12:
-#line 138 "sketch.y"
+#line 137 "sketch.y"
     { 
                             set_global_env_frame(global_env, (yyvsp[0].str), line);
                           }
     break;
 
   case 13:
-#line 142 "sketch.y"
+#line 141 "sketch.y"
     {
                             set_global_output_language(global_env, (yyvsp[0].index), line);
 		          }
     break;
 
   case 15:
-#line 148 "sketch.y"
+#line 147 "sketch.y"
     { (yyval.index) = (yyvsp[-1].index) | (yyvsp[0].index); }
     break;
 
   case 16:
-#line 151 "sketch.y"
+#line 150 "sketch.y"
     { (yyval.index) = GEOL_PSTRICKS; }
     break;
 
   case 17:
-#line 152 "sketch.y"
+#line 151 "sketch.y"
     { (yyval.index) = GEOL_TIKZ; }
     break;
 
   case 18:
-#line 155 "sketch.y"
+#line 154 "sketch.y"
     { (yyval.index) = (yyvsp[0].index); }
     break;
 
   case 19:
-#line 156 "sketch.y"
+#line 155 "sketch.y"
     { (yyval.index) = GEOL_LATEX; }
     break;
 
   case 20:
-#line 159 "sketch.y"
+#line 158 "sketch.y"
     { (yyval.index) = GEOL_LATEX; }
     break;
 
   case 21:
-#line 160 "sketch.y"
+#line 159 "sketch.y"
     { (yyval.index) = GEOL_CONTEXT; }
     break;
 
   case 22:
-#line 163 "sketch.y"
+#line 162 "sketch.y"
     { (yyval.flt) = (yyvsp[-1].flt); }
     break;
 
   case 23:
-#line 164 "sketch.y"
+#line 163 "sketch.y"
     { (yyval.flt) = NO_BASELINE; }
     break;
 
   case 24:
-#line 167 "sketch.y"
+#line 166 "sketch.y"
     { (yyval.obj) = sibling_reverse((yyvsp[0].obj)); }
     break;
 
   case 25:
-#line 170 "sketch.y"
+#line 169 "sketch.y"
     { (yyval.obj) = cat_objects((yyvsp[0].obj), (yyvsp[-1].obj)); }
     break;
 
   case 26:
-#line 171 "sketch.y"
+#line 170 "sketch.y"
     { (yyval.obj) = (yyvsp[0].obj); }
     break;
 
   case 27:
-#line 174 "sketch.y"
+#line 173 "sketch.y"
     { (yyval.obj) = NULL; }
     break;
 
   case 28:
-#line 175 "sketch.y"
+#line 174 "sketch.y"
     { (yyval.obj) = (yyvsp[0].obj); }
     break;
 
   case 29:
-#line 179 "sketch.y"
+#line 178 "sketch.y"
     { new_symbol(sym_tab, (yyvsp[-1].name), 0, (yyvsp[0].obj), line); }
     break;
 
   case 30:
-#line 180 "sketch.y"
+#line 179 "sketch.y"
     { new_symbol(sym_tab, (yyvsp[-2].name), 0, (yyvsp[0].obj), line); }
     break;
 
   case 31:
-#line 181 "sketch.y"
+#line 180 "sketch.y"
     { new_symbol(sym_tab, (yyvsp[-1].name), 0, new_tag_def(), line); }
     break;
 
   case 32:
-#line 184 "sketch.y"
+#line 183 "sketch.y"
     { strcpy((yyval.name), new_symbol(sym_tab, (yyvsp[-2].name), (yyvsp[-1].name), (yyvsp[0].obj), line) ? "" : (yyvsp[-2].name)); }
     break;
 
   case 33:
-#line 185 "sketch.y"
+#line 184 "sketch.y"
     { strcpy((yyval.name), new_symbol(sym_tab, (yyvsp[-2].name), (yyvsp[-1].name), (yyvsp[0].obj), line) ? "" : (yyvsp[-2].name)); }
     break;
 
   case 34:
-#line 188 "sketch.y"
+#line 187 "sketch.y"
     { (yyval.obj) = object_from_expr(&(yyvsp[0].exv)); }
     break;
 
   case 35:
-#line 189 "sketch.y"
+#line 188 "sketch.y"
     { (yyval.obj) = (yyvsp[0].obj); }
     break;
 
   case 36:
-#line 190 "sketch.y"
+#line 189 "sketch.y"
     { (yyval.obj) = new_opts_def((yyvsp[0].str), line); }
     break;
 
   case 37:
-#line 193 "sketch.y"
+#line 192 "sketch.y"
     { (yyval.obj) = new_dots((yyvsp[-1].opts), (yyvsp[0].obj)); }
     break;
 
   case 38:
-#line 194 "sketch.y"
+#line 193 "sketch.y"
     { (yyval.obj) = new_line((yyvsp[-1].opts), (yyvsp[0].obj)); }
     break;
 
   case 39:
-#line 195 "sketch.y"
+#line 194 "sketch.y"
     { (yyval.obj) = new_curve((yyvsp[-1].opts), (yyvsp[0].obj)); }
     break;
 
   case 40:
-#line 196 "sketch.y"
+#line 195 "sketch.y"
     { (yyval.obj) = new_polygon((yyvsp[-1].opts), (yyvsp[0].obj)); }
     break;
 
   case 41:
-#line 198 "sketch.y"
+#line 197 "sketch.y"
     { 
 						                (yyval.obj) = new_sweep((yyvsp[-7].opts), (yyvsp[-5].flt), (yyvsp[-4].bool), (yyvsp[-2].obj), new_point_def((yyvsp[0].pt)));
 						              }
     break;
 
   case 42:
-#line 202 "sketch.y"
+#line 201 "sketch.y"
     {
 						                (yyval.obj) = new_sweep((yyvsp[-7].opts), (yyvsp[-5].flt), (yyvsp[-4].bool), (yyvsp[-2].obj), (yyvsp[0].obj));
 						              }
     break;
 
   case 43:
-#line 206 "sketch.y"
+#line 205 "sketch.y"
     {
 						                (yyval.obj) = new_repeat((yyvsp[-4].flt), (yyvsp[-2].obj), (yyvsp[0].obj));
 						              }
     break;
 
   case 44:
-#line 209 "sketch.y"
+#line 208 "sketch.y"
     { (yyval.obj) = new_compound((yyvsp[-2].xf), (yyvsp[0].obj)); }
     break;
 
   case 45:
-#line 210 "sketch.y"
+#line 209 "sketch.y"
     { (yyval.obj) = new_special((yyvsp[-2].str), (yyvsp[-1].opts), (yyvsp[0].obj), line); }
     break;
 
   case 46:
-#line 211 "sketch.y"
+#line 210 "sketch.y"
     { (yyval.obj) = new_special((yyvsp[-1].str), (yyvsp[0].opts), new_point_def(origin_3d), line); }
     break;
 
   case 47:
-#line 212 "sketch.y"
+#line 211 "sketch.y"
     { look_up_drawable(sym_tab, &(yyval.obj), line, (yyvsp[0].name)); }
     break;
 
   case 48:
-#line 213 "sketch.y"
+#line 212 "sketch.y"
     { sym_tab = new_scope(sym_tab); }
     break;
 
   case 49:
-#line 214 "sketch.y"
+#line 213 "sketch.y"
     { sym_tab = old_scope(sym_tab); }
     break;
 
   case 50:
-#line 216 "sketch.y"
+#line 215 "sketch.y"
     {
                             if ((yyvsp[-2].obj) == NULL)
                               err(line, "no drawables in compound declaration");
@@ -1753,24 +1752,24 @@ yyreduce:
     break;
 
   case 51:
-#line 223 "sketch.y"
+#line 222 "sketch.y"
     { (yyval.bool) = 1; }
     break;
 
   case 52:
-#line 224 "sketch.y"
+#line 223 "sketch.y"
     { (yyval.bool) = 0; }
     break;
 
   case 53:
-#line 228 "sketch.y"
+#line 227 "sketch.y"
     { 
                             (yyval.opts) = look_up_and_append_to_opts(sym_tab, &(yyvsp[-2].opts), line, (yyvsp[0].name));
 			  }
     break;
 
   case 54:
-#line 232 "sketch.y"
+#line 231 "sketch.y"
     { 
                             (yyval.opts) = NULL;
                             (yyval.opts) = look_up_and_append_to_opts(sym_tab, &(yyval.opts), line, (yyvsp[0].name));
@@ -1778,220 +1777,220 @@ yyreduce:
     break;
 
   case 55:
-#line 238 "sketch.y"
+#line 237 "sketch.y"
     { (yyval.opts) = new_opts((yyvsp[0].str), line); }
     break;
 
   case 56:
-#line 239 "sketch.y"
+#line 238 "sketch.y"
     { look_up_opts(sym_tab, &(yyval.opts), line, (yyvsp[0].name)); }
     break;
 
   case 57:
-#line 240 "sketch.y"
+#line 239 "sketch.y"
     { (yyval.opts) = (yyvsp[-1].opts); }
     break;
 
   case 58:
-#line 241 "sketch.y"
+#line 240 "sketch.y"
     { (yyval.opts) = NULL; }
     break;
 
   case 59:
-#line 244 "sketch.y"
+#line 243 "sketch.y"
     { (yyval.obj) = sibling_reverse((yyvsp[0].obj)); }
     break;
 
   case 60:
-#line 247 "sketch.y"
+#line 246 "sketch.y"
     { (yyval.obj) = cat_objects(new_point_def((yyvsp[0].pt)), (yyvsp[-1].obj)); }
     break;
 
   case 61:
-#line 248 "sketch.y"
+#line 247 "sketch.y"
     { (yyval.obj) = new_point_def((yyvsp[0].pt)); }
     break;
 
   case 62:
-#line 251 "sketch.y"
+#line 250 "sketch.y"
     { (yyval.obj) = sibling_reverse((yyvsp[0].obj)); }
     break;
 
   case 63:
-#line 254 "sketch.y"
+#line 253 "sketch.y"
     { (yyval.obj) = cat_objects(new_transform_def((yyvsp[0].xf)), (yyvsp[-2].obj)); }
     break;
 
   case 64:
-#line 255 "sketch.y"
+#line 254 "sketch.y"
     { (yyval.obj) = new_transform_def((yyvsp[0].xf)); }
     break;
 
   case 65:
-#line 258 "sketch.y"
+#line 257 "sketch.y"
     { set_float(&(yyval.exv), (yyvsp[0].flt)); }
     break;
 
   case 66:
-#line 259 "sketch.y"
+#line 258 "sketch.y"
     { set_point(&(yyval.exv), (yyvsp[0].pt)); }
     break;
 
   case 67:
-#line 260 "sketch.y"
+#line 259 "sketch.y"
     { set_vector(&(yyval.exv), (yyvsp[0].vec)); }
     break;
 
   case 68:
-#line 261 "sketch.y"
+#line 260 "sketch.y"
     { set_transform(&(yyval.exv), (yyvsp[0].xf)); }
     break;
 
   case 69:
-#line 262 "sketch.y"
+#line 261 "sketch.y"
     { do_add(&(yyval.exv), &(yyvsp[-2].exv), &(yyvsp[0].exv), line); }
     break;
 
   case 70:
-#line 263 "sketch.y"
+#line 262 "sketch.y"
     { do_sub(&(yyval.exv), &(yyvsp[-2].exv), &(yyvsp[0].exv), line); }
     break;
 
   case 71:
-#line 264 "sketch.y"
+#line 263 "sketch.y"
     { do_mul(&(yyval.exv), &(yyvsp[-2].exv), &(yyvsp[0].exv), line); }
     break;
 
   case 72:
-#line 265 "sketch.y"
+#line 264 "sketch.y"
     { do_dvd(&(yyval.exv), &(yyvsp[-2].exv), &(yyvsp[0].exv), line); }
     break;
 
   case 73:
-#line 266 "sketch.y"
+#line 265 "sketch.y"
     { do_dot(&(yyval.exv), &(yyvsp[-2].exv), &(yyvsp[0].exv), line); }
     break;
 
   case 74:
-#line 267 "sketch.y"
+#line 266 "sketch.y"
     { do_thn(&(yyval.exv), &(yyvsp[-2].exv), &(yyvsp[0].exv), line); }
     break;
 
   case 75:
-#line 268 "sketch.y"
+#line 267 "sketch.y"
     { do_mag(&(yyval.exv), &(yyvsp[-1].exv), line); }
     break;
 
   case 76:
-#line 269 "sketch.y"
+#line 268 "sketch.y"
     { do_neg(&(yyval.exv), &(yyvsp[0].exv), line); }
     break;
 
   case 77:
-#line 270 "sketch.y"
+#line 269 "sketch.y"
     { do_pwr(&(yyval.exv), &(yyvsp[-2].exv), &(yyvsp[0].exv), line); }
     break;
 
   case 78:
-#line 271 "sketch.y"
+#line 270 "sketch.y"
     { (yyval.exv) = (yyvsp[-1].exv); }
     break;
 
   case 79:
-#line 272 "sketch.y"
+#line 271 "sketch.y"
     { do_unit(&(yyval.exv), &(yyvsp[-1].exv), line); }
     break;
 
   case 80:
-#line 273 "sketch.y"
+#line 272 "sketch.y"
     { do_sqrt(&(yyval.exv), &(yyvsp[-1].exv), line); }
     break;
 
   case 81:
-#line 274 "sketch.y"
+#line 273 "sketch.y"
     { do_sin(&(yyval.exv), &(yyvsp[-1].exv), line); }
     break;
 
   case 82:
-#line 275 "sketch.y"
+#line 274 "sketch.y"
     { do_cos(&(yyval.exv), &(yyvsp[-1].exv), line); }
     break;
 
   case 83:
-#line 276 "sketch.y"
+#line 275 "sketch.y"
     { do_atan2(&(yyval.exv), &(yyvsp[-3].exv), &(yyvsp[-1].exv), line); }
     break;
 
   case 84:
-#line 277 "sketch.y"
+#line 276 "sketch.y"
     { do_index(&(yyval.exv), &(yyvsp[-1].exv), (yyvsp[0].index), line); }
     break;
 
   case 85:
-#line 280 "sketch.y"
+#line 279 "sketch.y"
     { (yyval.flt) = (yyvsp[0].flt); }
     break;
 
   case 86:
-#line 281 "sketch.y"
+#line 280 "sketch.y"
     { look_up_scalar(sym_tab, &(yyval.flt), line, (yyvsp[0].name)); }
     break;
 
   case 87:
-#line 284 "sketch.y"
+#line 283 "sketch.y"
     { coerce_to_float(&(yyvsp[0].exv), &(yyval.flt), line); }
     break;
 
   case 88:
-#line 288 "sketch.y"
+#line 287 "sketch.y"
     { 
                             (yyval.pt)[X] = (yyvsp[-5].flt); (yyval.pt)[Y] = (yyvsp[-3].flt); (yyval.pt)[Z] = (yyvsp[-1].flt);
                           }
     break;
 
   case 89:
-#line 292 "sketch.y"
+#line 291 "sketch.y"
     { 
                             (yyval.pt)[X] = (yyvsp[-3].flt); (yyval.pt)[Y] = (yyvsp[-1].flt); (yyval.pt)[Z] = 0;
                           }
     break;
 
   case 90:
-#line 295 "sketch.y"
+#line 294 "sketch.y"
     { look_up_point(sym_tab, (yyval.pt), line, (yyvsp[0].name)); }
     break;
 
   case 91:
-#line 298 "sketch.y"
+#line 297 "sketch.y"
     { coerce_to_point(&(yyvsp[0].exv), (yyval.pt), line); }
     break;
 
   case 92:
-#line 302 "sketch.y"
+#line 301 "sketch.y"
     { 
                             (yyval.vec)[X] = (yyvsp[-5].flt); (yyval.vec)[Y] = (yyvsp[-3].flt); (yyval.vec)[Z] = (yyvsp[-1].flt);
                           }
     break;
 
   case 93:
-#line 306 "sketch.y"
+#line 305 "sketch.y"
     { 
                             (yyval.vec)[X] = (yyvsp[-3].flt); (yyval.vec)[Y] = (yyvsp[-1].flt); (yyval.vec)[Z] = 0;
                           }
     break;
 
   case 94:
-#line 309 "sketch.y"
+#line 308 "sketch.y"
     { look_up_vector(sym_tab, (yyval.vec), line, (yyvsp[0].name)); }
     break;
 
   case 95:
-#line 311 "sketch.y"
+#line 310 "sketch.y"
     { coerce_to_vector(&(yyvsp[0].exv), (yyval.vec), line); }
     break;
 
   case 96:
-#line 320 "sketch.y"
+#line 319 "sketch.y"
     { // transform is column major while elements are row major
                             (yyval.xf)[0] = (yyvsp[-35].flt);  (yyval.xf)[4] = (yyvsp[-33].flt);  (yyval.xf)[8]  = (yyvsp[-31].flt);  (yyval.xf)[12] = (yyvsp[-29].flt);
                             (yyval.xf)[1] = (yyvsp[-26].flt); (yyval.xf)[5] = (yyvsp[-24].flt); (yyval.xf)[9]  = (yyvsp[-22].flt); (yyval.xf)[13] = (yyvsp[-20].flt);
@@ -2001,14 +2000,14 @@ yyreduce:
     break;
 
   case 97:
-#line 327 "sketch.y"
+#line 326 "sketch.y"
     {
                             set_angle_axis_rot_about_point((yyval.xf), (yyvsp[-1].flt) * (PI/180), 0, 0);
                           }
     break;
 
   case 98:
-#line 331 "sketch.y"
+#line 330 "sketch.y"
     {
                             if (EXPR_TYPE_IS(&(yyvsp[-1].exv), E_POINT))
                               set_angle_axis_rot_about_point((yyval.xf), (yyvsp[-3].flt) * (PI/180), (yyvsp[-1].exv).val.pt, 0);
@@ -2021,21 +2020,21 @@ yyreduce:
     break;
 
   case 99:
-#line 341 "sketch.y"
+#line 340 "sketch.y"
     {
                             set_angle_axis_rot_about_point((yyval.xf), (yyvsp[-5].flt) * (PI/180), (yyvsp[-3].pt), (yyvsp[-1].vec));
                           }
     break;
 
   case 100:
-#line 345 "sketch.y"
+#line 344 "sketch.y"
     {
                             set_translation((yyval.xf), (yyvsp[-1].vec)[X], (yyvsp[-1].vec)[Y], (yyvsp[-1].vec)[Z]);
                           }
     break;
 
   case 101:
-#line 349 "sketch.y"
+#line 348 "sketch.y"
     {
                             if ((yyvsp[-1].exv).tag == E_FLOAT) {
                               FLOAT s = (yyvsp[-1].exv).val.flt;
@@ -2055,22 +2054,22 @@ yyreduce:
     break;
 
   case 102:
-#line 365 "sketch.y"
+#line 364 "sketch.y"
     { set_parallel_projection((yyval.xf)); }
     break;
 
   case 103:
-#line 366 "sketch.y"
+#line 365 "sketch.y"
     { set_perspective_projection((yyval.xf), (yyvsp[-1].flt)); }
     break;
 
   case 104:
-#line 367 "sketch.y"
+#line 366 "sketch.y"
     { set_perspective_transform((yyval.xf), (yyvsp[-1].flt)); }
     break;
 
   case 105:
-#line 369 "sketch.y"
+#line 368 "sketch.y"
     {
                             if ((yyvsp[-3].exv).tag == E_VECTOR)
                               set_view_transform((yyval.xf), (yyvsp[-5].pt), (yyvsp[-3].exv).val.vec, (yyvsp[-1].vec));
@@ -2083,7 +2082,7 @@ yyreduce:
     break;
 
   case 106:
-#line 379 "sketch.y"
+#line 378 "sketch.y"
     {
                             if ((yyvsp[-1].exv).tag == E_VECTOR)
                               set_view_transform((yyval.xf), (yyvsp[-3].pt), (yyvsp[-1].exv).val.vec, NULL);
@@ -2096,24 +2095,24 @@ yyreduce:
     break;
 
   case 107:
-#line 389 "sketch.y"
+#line 388 "sketch.y"
     {
                             set_view_transform((yyval.xf), (yyvsp[-1].pt), NULL, NULL);
                           }
     break;
 
   case 108:
-#line 393 "sketch.y"
+#line 392 "sketch.y"
     { do_inverse((yyval.xf), (yyvsp[-1].xf), line); }
     break;
 
   case 109:
-#line 394 "sketch.y"
+#line 393 "sketch.y"
     { look_up_transform(sym_tab, (yyval.xf), line, (yyvsp[0].name)); }
     break;
 
   case 110:
-#line 397 "sketch.y"
+#line 396 "sketch.y"
     { coerce_to_transform(&(yyvsp[0].exv), (yyval.xf), line); }
     break;
 
@@ -2122,7 +2121,7 @@ yyreduce:
     }
 
 /* Line 1126 of yacc.c.  */
-#line 2126 "y.tab.c"
+#line 2125 "y.tab.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2390,7 +2389,7 @@ yyreturn:
 }
 
 
-#line 400 "sketch.y"
+#line 399 "sketch.y"
 
 
 int parse(SYMBOL_TABLE *st)
